@@ -1,10 +1,10 @@
-# @(#)$Id: Chooser.pm 312 2011-06-26 19:36:57Z pjf $
+# @(#)$Id: Chooser.pm 334 2011-12-12 04:30:18Z pjf $
 
 package HTML::FormWidgets::Chooser;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 312 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(config field href) );
@@ -26,7 +26,7 @@ sub render_field {
 
    $self->config->{field} = '"'.$self->field.'"';
    $self->config->{href } = '"'.$self->href.'"';
-   $self->_js_config( 'anchors', $self->id, $self->config );
+   $self->add_literal_js( 'anchors', $self->id, $self->config );
 
    return $self->hacc->submit( { class => $self->class,
                                  id    => $self->id,
