@@ -1,19 +1,20 @@
-# @(#)$Id: Cloud.pm 312 2011-06-26 19:36:57Z pjf $
+# @(#)$Id: Cloud.pm 334 2011-12-12 04:30:18Z pjf $
 
 package HTML::FormWidgets::Cloud;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 312 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
-__PACKAGE__->mk_accessors( qw(data) );
+__PACKAGE__->mk_accessors( qw(data height) );
 
 sub init {
    my ($self, $args) = @_;
 
    $self->container( 0  );
    $self->data     ( {} );
+   $self->height   ( 18 );
    return;
 }
 
@@ -30,32 +31,34 @@ sub render_field {
       my $attrs      = { class   => $class_pref.q(_header fade live_grid),
                          href    => $href,
                          id      => $id };
+
       if ($item->{size}) {
-         # Assumes 1em = 10px and line height = 1.8em
-         my $mult        = 1 + int ($item->{size} / 1.8);
-         my $line_height = (int 0.5 + (1800 * $mult / $item->{size})) / 1000;
+         # Assumes 1em = 10px
+         my $mult        = 1 + int (10 * $item->{size} / $self->height);
+         my $height      = $mult * $self->height;
+         my $line_height = (int 0.5 + (100 * $height / $item->{size})) / 1000;
 
          $style .= 'font-size: '.$item->{size}.'em; ';
-         $style .= 'line-height: '.$line_height.'em; ';
-         $style .= 'height: '.(18 * $mult).'px; ';
+         $style .= "line-height: ${line_height}em; ";
+         $style .= "height: ${height}px; ";
       }
 
       $item->{colour} and $style .= 'color: '.$item->{colour}.'; ';
       $style and $attrs->{style}  = $style;
 
-      my $text    = $ref->{labels}->{ $ref->{name} };
-         $text   .= '('.$ref->{total}.')' if exists $ref->{total};
-      my $anchor  = $hacc->a( $attrs, "\n".$text );
-      my $class   = $class_pref.q(_header).q( ).$class_pref.q(Subject);
+      my $text   = $ref->{labels}->{ $ref->{name} };
+         $text  .= '('.$ref->{total}.')' if exists $ref->{total};
+      my $anchor = $hacc->a( $attrs, "\n".$text );
 
-      $html      .= $hacc->div( { class => $class }, "\n".$anchor )."\n";
+      $attrs     = { class => $class_pref.q(_header) };
+      $html     .= $hacc->div( $attrs, "\n".$anchor )."\n";
 
-      if (not $ref->{href}) {
-         $style   = 'display: none; width: '.$ref->{width}.'px;';
-         $html   .= $hacc->div( { class => $class_pref.q(Panel),
-                                  id    => $id.q(Disp),
-                                  style => $style }, 'Loading...' );
-      }
+      $ref->{href} and next;
+
+      $style     = 'display: none; width: '.$ref->{width}.'px;';
+      $html     .= $hacc->div( { class => $class_pref.q(_panel),
+                                 id    => $id.q(Disp),
+                                 style => $style }, 'Loading...' );
    }
 
    return $html;
