@@ -1,10 +1,10 @@
-# @(#)$Id: Image.pm 312 2011-06-26 19:36:57Z pjf $
+# @(#)$Id: Image.pm 334 2011-12-12 04:30:18Z pjf $
 
 package HTML::FormWidgets::Image;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 312 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(fhelp) );
@@ -12,7 +12,7 @@ __PACKAGE__->mk_accessors( qw(fhelp) );
 sub init {
    my ($self, $args) = @_;
 
-   $self->fhelp(   q() );
+   $self->fhelp  ( q()       );
    $self->tiptype( q(normal) );
    return;
 }
@@ -20,9 +20,12 @@ sub init {
 sub render_field {
    my ($self, $args) = @_;
 
-   return $self->hacc->img( { alt   => $self->fhelp,
-                              class => $self->class,
-                              src   => $self->text } );
+   $args = { alt => $self->fhelp, src => $self->text };
+
+   $self->class and $args->{class} = $self->class;
+   $self->id    and $args->{id   } = $self->id;
+
+   return $self->hacc->img( $args );
 }
 
 1;
