@@ -1,10 +1,10 @@
-# @(#)$Id: Template.pm 312 2011-06-26 19:36:57Z pjf $
+# @(#)$Id: Template.pm 334 2011-12-12 04:30:18Z pjf $
 
 package HTML::FormWidgets::Template;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 312 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
 use parent q(HTML::FormWidgets);
 
 use English qw(-no_match_vars);
@@ -14,7 +14,8 @@ use IO::File;
 sub render_field {
    my ($self, $args) = @_;
 
-   my $path = File::Spec->catfile( $self->template_dir, $self->name.q(.tt) );
+   my $path = File::Spec->catfile( $self->options->{template_dir},
+                                   $self->name.q(.tt) );
 
    -f $path or return "Path $path not found";
 
@@ -23,7 +24,7 @@ sub render_field {
    my $content = do { local $RS = undef; <$rdr> }; $rdr->close();
    my $id      = $self->id;
 
-   return "[% ref = template_data.${id}; %]\n$content";
+   return "[% ref = template_data.${id}; %]\n${content}";
 }
 
 1;
