@@ -1,10 +1,10 @@
-# @(#)$Id: Textfield.pm 312 2011-06-26 19:36:57Z pjf $
+# @(#)$Id: Textfield.pm 334 2011-12-12 04:30:18Z pjf $
 
 package HTML::FormWidgets::Textfield;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 312 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(width) );
@@ -19,7 +19,7 @@ sub init {
 sub render_field {
    my ($self, $args) = @_;
 
-   $args->{class} .= q( ).($self->class || q(ifield));
+   $args->{class} .= ($args->{class} ? q( ): q()).($self->class || q(ifield));
    $args->{size }  = $self->width;
 
    return $self->hacc->textfield( $args );
